<?php
/**
 * @file
 * This file contains helper functions for openlucius.
 */

/**
 * Function to obtain an icon based on type / path.
 *
 * @param string $type
 *   Either the node type or the path.
 *
 * @return string
 *   Returns a usable glyphicon, defaults to globe.
 */
function openlucius_core_icons($type) {

  $icons = array(
    'ol_group'             => 'record',
    'file'                 => 'file',
    'ol_message'           => 'envelope',
    'ol_text_document'     => 'font',
    'ol_todo_list'         => 'list-alt',
    'ol_todo'              => 'inbox',
    'ol_event'             => 'calendar',
    'group-files'          => 'file',
    'all-files'            => 'file',
    'group-messages'       => 'envelope',
    'all-messages'         => 'envelope',
    'group-textdocuments'  => 'font',
    'all-text-documents'   => 'font',
    'group-todo-lists'     => 'list-alt',
    'all-todo-lists'       => 'list-alt',
    'group-calendar/month' => 'calendar',
    'all-calendar'         => 'calendar',
    'trash'                => 'trash',
    'archived-groups'      => 'folder-close',
    'comment'              => 'comment',
    'group-users'          => 'user',
    'all-users'            => 'user',
    'companies-teams'      => 'user',
    'blocked-users'        => 'user',
    'user-calendar'        => 'inbox',
    'search'               => 'search',
    'node_add'             => 'plus-sign',
  );

  // Allow other modules to add / edit icons.
  drupal_alter('openlucius_core_icons', $type);

  return isset($icons[$type]) ? $icons[$type] : 'globe';
}

/**
 * Function to fetch all user ids.
 * @return array
 *   Returns an array containing all of the active user id's.
 */
function openlucius_core_fetch_all_active_uids() {
  $users = db_select('users', 'u')
    ->fields('u', array('uid'))
    ->condition('status', 1, '=')
    ->execute()
    ->fetchAllKeyed(0, 0);

  return array_keys($users);
}

/**
 * Function for quickly loading a user image in a given style.
 *
 * @param mixed $u
 *   Either a user id or a fully loaded user object.
 *
 * @param string $style
 *   An image style to be applied to the image.
 *
 * @return string
 *   Returns the path to the styled image.
 *
 * @throws \Exception
 */
function openlucius_core_fetch_user_image($u, $style = 'ol_50x50') {

  // If u is a number it's the uid otherwise it is a user object.
  $account = is_numeric($u) ? user_load($u) : $u;

  // The default 'avatar' image.
  $default_uri = drupal_get_path('profile', 'openlucius') . '/themes/openlucius/images/avatar.png';

  // Check if the user has a picture.
  if (!empty($account->picture)) {

    // Check if the file was loaded.
    if (!empty($account->picture->uri)) {

      if (file_exists($account->picture->uri)) {
        $image = theme('image_style', array(
          'style_name' => $style,
          'path'       => $account->picture->uri,
        ));
      }
      else {
        $image = theme('image', array(
          'style_name' => 'ol_50x50',
          'path'       => $default_uri,
        ));
      }
    }
    // Build path to default picture.
    else {
      $image = theme('image', array(
        'style_name' => 'ol_50x50',
        'path'       => $default_uri,
      ));
    }
  }

  // Build path to default picture.
  else {
    $image = theme('image', array(
      'style_name' => 'ol_50x50',
      'path'       => $default_uri,
    ));
  }

  return $image;
}
